==> decoration-ioc-1.0.2.tgz: package/lib/descriptors.js <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var AbstractDescriptor = (function () {
    function AbstractDescriptor(_staticArguments) {
        this._staticArguments = _staticArguments;
        // empty
    }
    AbstractDescriptor.prototype.appendStaticArguments = function (more) {
        this._staticArguments.push.apply(this._staticArguments, more);
    };
    AbstractDescriptor.prototype.staticArguments = function (nth) {
        if (isNaN(nth)) {
            return this._staticArguments.slice(0);
        }
        else {
            return this._staticArguments[nth];
        }
    };
    AbstractDescriptor.prototype._validate = function (type) {
        if (!type) {
            throw new Error('can not be falsy');
        }
    };
    return AbstractDescriptor;
}());
exports.AbstractDescriptor = AbstractDescriptor;
var Descriptor = (function (_super) {
    __extends(Descriptor, _super);
    function Descriptor(_ctor) {
        var staticArguments = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            staticArguments[_i - 1] = arguments[_i];
        }
        _super.call(this, staticArguments);
        this._ctor = _ctor;
    }
    Object.defineProperty(Descriptor.prototype, "ctor", {
        get: function () {
            return this._ctor;
        },
        enumerable: true,
        configurable: true
    });
    Descriptor.prototype.bind = function () {
        var moreStaticArguments = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            moreStaticArguments[_i - 0] = arguments[_i];
        }
        var allArgs = [];
        allArgs = allArgs.concat(this.staticArguments());
        allArgs = allArgs.concat(moreStaticArguments);
        return new (Descriptor.bind.apply(Descriptor, [void 0].concat([this._ctor], allArgs)))();
    };
    return Descriptor;
}(AbstractDescriptor));
exports.Descriptor = Descriptor;
exports.createDescriptor = function (ctor) {
    var staticArguments = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        staticArguments[_i - 1] = arguments[_i];
    }
    return new (Descriptor.bind.apply(Descriptor, [void 0].concat([ctor], staticArguments)))();
};

==> decoration-ioc-1.1.0.tgz: package/lib/descriptors.js <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var AbstractDescriptor = (function () {
    function AbstractDescriptor(_staticArguments) {
        this._staticArguments = _staticArguments;
        // empty
    }
    AbstractDescriptor.prototype.appendStaticArguments = function (more) {
        this._staticArguments.push.apply(this._staticArguments, more);
    };
    AbstractDescriptor.prototype.staticArguments = function (nth) {
        if (isNaN(nth)) {
            return this._staticArguments.slice(0);
        }
        else {
            return this._staticArguments[nth];
        }
    };
    AbstractDescriptor.prototype._validate = function (type) {
        if (!type) {
            throw new Error("can not be falsy");
        }
    };
    return AbstractDescriptor;
}());
exports.AbstractDescriptor = AbstractDescriptor;
var Descriptor = (function (_super) {
    __extends(Descriptor, _super);
    function Descriptor(_ctor) {
        var staticArguments = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            staticArguments[_i - 1] = arguments[_i];
        }
        _super.call(this, staticArguments);
        this._ctor = _ctor;
    }
    Object.defineProperty(Descriptor.prototype, "ctor", {
        get: function () {
            return this._ctor;
        },
        enumerable: true,
        configurable: true
    });
    Descriptor.prototype.bind = function () {
        var moreStaticArguments = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            moreStaticArguments[_i - 0] = arguments[_i];
        }
        var allArgs = [];
        allArgs = allArgs.concat(this.staticArguments());
        allArgs = allArgs.concat(moreStaticArguments);
        return new (Descriptor.bind.apply(Descriptor, [void 0].concat([this._ctor], allArgs)))();
    };
    return Descriptor;
}(AbstractDescriptor));
exports.Descriptor = Descriptor;
exports.createDescriptor = function (ctor) {
    var staticArguments = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        staticArguments[_i - 1] = arguments[_i];
    }
    return new (Descriptor.bind.apply(Descriptor, [void 0].concat([ctor], staticArguments)))();
};
